chop.optim
==========

.. automodule:: chop.optim

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      backtracking_pgd
      minimize_frank_wolfe
      minimize_pgd
      minimize_pgd_madry
      minimize_three_split
   
   

   
   
   

   
   
   



